[WATCHDOG] w83697hf/hg WDT driver - patch 12

This is patch 12 in the series of patches that converts
Marcus Junker's w83697hf watchdog driver to Samuel Tardieau's
w83697hf/hg watchdog driver.

This patch contains following changes:
 - Add w83697hf_write_timeout() to set the
   watchdog's timeout value.

Signed-off-by: Samuel Tardieu <sam@rfc1149.net>
Signed-off-by: Wim Van Sebroeck <wim@iguana.be>

diff --git a/drivers/char/watchdog/w83697hf_wdt.c b/drivers/char/watchdog/w83697hf_wdt.c
index b12f8b8..b3dcc81 100644
--- a/drivers/char/watchdog/w83697hf_wdt.c
+++ b/drivers/char/watchdog/w83697hf_wdt.c
@@ -83,8 +83,8 @@
 }
 
 /*
  *	The two functions w83697hf_get_reg() and w83697hf_set_reg()
  *	must be called with the device unlocked.
  */
 
 static unsigned char
@@ -102,6 +102,12 @@
 }
 
 static void
+w83697hf_write_timeout(int timeout)
+{
+	w83697hf_set_reg(0xF4, timeout);	/* Write Timeout counter to CRF4 */
+}
+
+static void
 w83697hf_select_wdt(void)
 {
 	w83697hf_unlock();
@@ -157,7 +163,7 @@
 
 	w83697hf_select_wdt();
 
-	w83697hf_set_reg(0xF4, timeout);	/* Write Timeout counter to CRF4 */
+	w83697hf_write_timeout(timeout);
 
 	w83697hf_deselect_wdt();
@@ -83,8 +83,8 @@
 
 /*
- *	The two functions w83697hf_get_reg() and w83697hf_set_reg()
- *	must be called with the device unlocked.
+ *	The three functions w83697hf_get_reg(), w83697hf_set_reg() and
+ *	w83697hf_write_timeout() must be called with the device unlocked.
  */
 